
def _create_class(name:str, superclasses:tuple, properties:dict):
    new_class = type(name, superclasses, properties)

    for k,v in properties.items():
        if 'dict' in str(type(v)):
            another_class = _create_class(k,(),v)
            setattr(new_class,k, another_class)
    return new_class


class_name = "MainClass"
super_class= tuple()
def load(json_dictionary):
    result = _create_class(class_name,(super_class), json_dictionary)
    return result















from distutils.core import setup
setup(
  name = 'access_dict_by_dot',
  packages = ['access_dict_by_dot'],
  version = '0.0.1',
  license='MIT',
  description = 'Using this packages we can access dictionary values using dot operator',
  author = 'Indrajeet Singh',
  author_email = 'indrajeetsinghmaan@gmail.com',
  url = 'https://github.com/ismaan1998/access_dict_by_dot/',
  download_url = 'https://github.com/ismaan1998/access_dict_by_dot/releases/tag/0.0.1',
  keywords = ['dictionary', 'dot', 'access'],

  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
  ],
)